==> nextcloud-31.0.10.tgz: nextcloud/3rdparty/aws/aws-sdk-php/src/KinesisVideo/KinesisVideoClient.php <==
<?php
namespace Aws\KinesisVideo;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Kinesis Video Streams** service.
 * @method \Aws\Result createSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createSignalingChannelAsync(array $args = [])
 * @method \Aws\Result createStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createStreamAsync(array $args = [])
 * @method \Aws\Result deleteEdgeConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteEdgeConfigurationAsync(array $args = [])
 * @method \Aws\Result deleteSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteSignalingChannelAsync(array $args = [])
 * @method \Aws\Result deleteStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteStreamAsync(array $args = [])
 * @method \Aws\Result describeEdgeConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeEdgeConfigurationAsync(array $args = [])
 * @method \Aws\Result describeImageGenerationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeImageGenerationConfigurationAsync(array $args = [])
 * @method \Aws\Result describeMappedResourceConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeMappedResourceConfigurationAsync(array $args = [])
 * @method \Aws\Result describeMediaStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeMediaStorageConfigurationAsync(array $args = [])
 * @method \Aws\Result describeNotificationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeNotificationConfigurationAsync(array $args = [])
 * @method \Aws\Result describeSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeSignalingChannelAsync(array $args = [])
 * @method \Aws\Result describeStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStreamAsync(array $args = [])
 * @method \Aws\Result getDataEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getDataEndpointAsync(array $args = [])
 * @method \Aws\Result getSignalingChannelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSignalingChannelEndpointAsync(array $args = [])
 * @method \Aws\Result listEdgeAgentConfigurations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEdgeAgentConfigurationsAsync(array $args = [])
 * @method \Aws\Result listSignalingChannels(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listSignalingChannelsAsync(array $args = [])
 * @method \Aws\Result listStreams(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listStreamsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result listTagsForStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForStreamAsync(array $args = [])
 * @method \Aws\Result startEdgeConfigurationUpdate(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startEdgeConfigurationUpdateAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result tagStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagStreamAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result untagStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagStreamAsync(array $args = [])
 * @method \Aws\Result updateDataRetention(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateDataRetentionAsync(array $args = [])
 * @method \Aws\Result updateImageGenerationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateImageGenerationConfigurationAsync(array $args = [])
 * @method \Aws\Result updateMediaStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateMediaStorageConfigurationAsync(array $args = [])
 * @method \Aws\Result updateNotificationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateNotificationConfigurationAsync(array $args = [])
 * @method \Aws\Result updateSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateSignalingChannelAsync(array $args = [])
 * @method \Aws\Result updateStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateStreamAsync(array $args = [])
 */
class KinesisVideoClient extends AwsClient {}

==> nextcloud-31.0.13.tgz: nextcloud/3rdparty/aws/aws-sdk-php/src/KinesisVideo/KinesisVideoClient.php <==
<?php
namespace Aws\KinesisVideo;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Kinesis Video Streams** service.
 * @method \Aws\Result createSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createSignalingChannelAsync(array $args = [])
 * @method \Aws\Result createStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createStreamAsync(array $args = [])
 * @method \Aws\Result deleteEdgeConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteEdgeConfigurationAsync(array $args = [])
 * @method \Aws\Result deleteSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteSignalingChannelAsync(array $args = [])
 * @method \Aws\Result deleteStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteStreamAsync(array $args = [])
 * @method \Aws\Result describeEdgeConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeEdgeConfigurationAsync(array $args = [])
 * @method \Aws\Result describeImageGenerationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeImageGenerationConfigurationAsync(array $args = [])
 * @method \Aws\Result describeMappedResourceConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeMappedResourceConfigurationAsync(array $args = [])
 * @method \Aws\Result describeMediaStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeMediaStorageConfigurationAsync(array $args = [])
 * @method \Aws\Result describeNotificationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeNotificationConfigurationAsync(array $args = [])
 * @method \Aws\Result describeSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeSignalingChannelAsync(array $args = [])
 * @method \Aws\Result describeStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStreamAsync(array $args = [])
 * @method \Aws\Result describeStreamStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStreamStorageConfigurationAsync(array $args = [])
 * @method \Aws\Result getDataEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getDataEndpointAsync(array $args = [])
 * @method \Aws\Result getSignalingChannelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSignalingChannelEndpointAsync(array $args = [])
 * @method \Aws\Result listEdgeAgentConfigurations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEdgeAgentConfigurationsAsync(array $args = [])
 * @method \Aws\Result listSignalingChannels(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listSignalingChannelsAsync(array $args = [])
 * @method \Aws\Result listStreams(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listStreamsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result listTagsForStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForStreamAsync(array $args = [])
 * @method \Aws\Result startEdgeConfigurationUpdate(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startEdgeConfigurationUpdateAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result tagStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagStreamAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result untagStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagStreamAsync(array $args = [])
 * @method \Aws\Result updateDataRetention(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateDataRetentionAsync(array $args = [])
 * @method \Aws\Result updateImageGenerationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateImageGenerationConfigurationAsync(array $args = [])
 * @method \Aws\Result updateMediaStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateMediaStorageConfigurationAsync(array $args = [])
 * @method \Aws\Result updateNotificationConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateNotificationConfigurationAsync(array $args = [])
 * @method \Aws\Result updateSignalingChannel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateSignalingChannelAsync(array $args = [])
 * @method \Aws\Result updateStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateStreamAsync(array $args = [])
 * @method \Aws\Result updateStreamStorageConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateStreamStorageConfigurationAsync(array $args = [])
 */
class KinesisVideoClient extends AwsClient {}
